import tseslint from '@electron-toolkit/eslint-config-ts'
import eslintConfigPrettier from '@electron-toolkit/eslint-config-prettier'
import eslintPluginVue from 'eslint-plugin-vue'
import vueParser from 'vue-eslint-parser'

export default tseslint.config(
  { ignores: ['**/node_modules', '**/dist', '**/out'] },
  tseslint.configs.recommended,
  eslintPluginVue.configs['flat/recommended'],
  {
    files: ['**/*.vue'],
    languageOptions: {
      parser: vueParser,
      parserOptions: {
        ecmaFeatures: {
          jsx: true
        },
        extraFileExtensions: ['.vue'],
        parser: tseslint.parser
      }
    }
  },
  {
    files: ['**/*.{ts,mts,tsx,vue}'],
    rules: {
      'vue/require-default-prop': 'off',
      'vue/multi-word-component-names': 'off',

    // eslint (http://eslint.cn/docs/rules)
    'no-useless-escape': 0, // 关闭不必要的转义
    'no-var': 'error', // 要求使用 let 或 const 而不是 var
    'no-multiple-empty-lines': ['error', { max: 1 }], // 不允许多个空行
    'prefer-const': 1, // 使用 let 关键字声明但在初始分配后从未重新分配的变量，要求使用 const
    'no-use-before-define': 0, // 禁止在 函数/类/变量 定义之前使用它们
    'prettier/prettier': [
      'warn',
      {
        singleQuote: true,
        semi: false
      }
    ],
    // typeScript (https://typescript-eslint.io/rules)
    '@typescript-eslint/no-unused-vars': 0, // 禁止定义未使用的变量
    '@typescript-eslint/no-empty-function': 0, // 禁止空函数
    'no-empty': 0, // 判据可以为空
    '@typescript-eslint/prefer-ts-expect-error': 'error', // 禁止使用 @ts-ignore
    '@typescript-eslint/ban-ts-comment': 'error', // 禁止 @ts-<directive> 使用注释或要求在指令后进行描述
    '@typescript-eslint/no-inferrable-types': 0, // 可以轻松推断的显式类型可能会增加不必要的冗长
    '@typescript-eslint/no-namespace': 0, // 禁止使用自定义 TypeScript 模块和命名空间
    '@typescript-eslint/no-explicit-any': 0, // 禁止使用 any 类型
    '@typescript-eslint/ban-types': 0, // 禁止使用特定类型
    '@typescript-eslint/no-var-requires': 0, // 允许使用 require() 函数导入模块
    '@typescript-eslint/no-non-null-assertion': 0, // 不允许使用后缀运算符的非空断言(!)
    '@typescript-eslint/no-unused-expressions': 0, // 方法可以不返回
    // vue (https://eslint.vuejs.org/rules)
    'vue/script-setup-uses-vars': 'error', // 防止<script setup>使用的变量<template>被标记为未使用，此规则仅在启用该 no-unused-vars 规则时有效
    'vue/v-slot-style': 'error', // 强制执行 v-slot 指令样式
    'vue/no-mutating-props': 'error', // 不允许改变组件 prop
    'vue/custom-event-name-casing': 'error', // 为自定义事件名称强制使用特定大小写
    'vue/attribute-hyphenation': 'error', // 对模板中的自定义组件强制执行属性命名样式：my-prop="prop"
    'vue/attributes-order': 0, // vue api使用顺序，强制执行属性顺序
    'vue/no-v-html': 0, // 禁止使用 v-html
    'vue/require-default-prop': 0, // 此规则要求为每个 prop 为必填时，必须提供默认值
    'vue/multi-word-component-names': 0, // 要求组件名称始终为 “-” 链接的单词
    'vue/no-setup-props-destructure': 0, // 禁止解构 props 传递给 setup
    // singleline...单行元素的配置。如果元素没有属性或最后一个属性与左括号位于同一行，则它是单行元素。"never"（默认）...不允许在右括号前换行。"always"...要求在右括号前有一个换行符。
    // multiline...多行元素的配置。如果最后一个属性不在左括号的同一行上，则它是一个多行元素。"never"...不允许在右括号前换行。"always"（默认）...要求在右括号前有一个换行符。
    'vue/html-closing-bracket-newline': [
      'error',
      {
        singleline: 'never',
        multiline: 'never'
      }
    ],
      'vue/block-lang': [
        'error',
        {
          script: {
            lang: 'ts'
          }
        }
      ]
    }
  },
  eslintConfigPrettier
)
